# Welcome to Squish Alert Close

![](src/images/about.png=250x)
## Installation

Run setup.py
requirements:
[opencv-python](https://pypi.org/project/opencv-python)
[pyautogui](https://pypi.org/project/PyAutoGUI)
[comtypes](https://pypi.org/project/comtypes)


## Licensing

See the [LICENSE](LICENSE) file for details.

## About Squish Alert Close

This module closes the error window that occurs due to server squash memory leaks (Windows 8 and higher).